@@ -2,8 +2,8 @@ from cookiecutter.exceptions import (
     CookiecutterException,
     UndefinedVariableInTemplate,
 )
-from cookiecutter_python.backend.check_pypi import ContextVariableDoesNotExist
-from cookiecutter_python.backend import CheckPypiError
+from cookiecutter_python.backend.hosting_services.exceptions import ContextVariableDoesNotExist
+from cookiecutter_python.backend import CheckWebServerError
 from cookiecutter_python.utils import load
 
 cookiecutter_exceptions = load(CookiecutterException, 'cookiecutter')
@@ -12,7 +12,7 @@ cookiecutter_exceptions = load(CookiecutterException, 'cookiecutter')
 exceptions = {
     'critical': cookiecutter_exceptions + [ContextVariableDoesNotExist],  # type: ignore
     'non-critical': (
-        CheckPypiError,
+        CheckWebServerError,
     )
 }
 
